# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_simple import CourseSimple

class TestCourseSimple(unittest.TestCase):
    """CourseSimple unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseSimple:
        """Test CourseSimple
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseSimple`
        """
        model = CourseSimple()
        if include_optional:
            return CourseSimple(
                title = '',
                image_id = '',
                description = '',
                url = '',
                payload = '',
                module_view_type = 'list',
                payment_type = 'paid',
                course_access_type = 'subscription',
                number_days_access = 56,
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                available_at = 56,
                launch_date_enabled = True,
                launch_date = 56,
                id = 56,
                portal_id = 56,
                order = 56,
                category = '',
                category_id = 56,
                sales_page_landing_id = 56,
                permalink = '',
                enable_double_optin = True,
                one_more_landing_id = 56,
                one_more_step_link = '',
                one_more_step_landing_id = 56,
                created_at_epoch = 56
            )
        else:
            return CourseSimple(
                title = '',
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                id = 56,
                portal_id = 56,
                order = 56,
                created_at_epoch = 56,
        )
        """

    def testCourseSimple(self):
        """Test CourseSimple"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.button_position import ButtonPosition
from public_api_server_connector_v2.models.button_size import ButtonSize
from public_api_server_connector_v2.models.button_target import ButtonTarget
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class Content(BaseModel):
    """
    Content
    """ # noqa: E501
    link: Optional[StrictStr] = Field(default=None, description="Link to the content, e.g. YouTube video link")
    file_id: Optional[StrictStr] = Field(default=None, description="File id from the file storage service")
    audio_id: Optional[StrictStr] = Field(default=None, description="Audio id for audio content blocks")
    payload: Optional[StrictStr] = Field(default=None, description="Raw content payload, e.g. HTML or text content")
    btn_url: Optional[StrictStr] = Field(default=None, description="Button URL, has to be set if the block is a button")
    btn_font: Optional[StrictStr] = Field(default=None, description="Button font, if not set, default font (Public Sans) is used")
    btn_size: Optional[ButtonSize] = Field(default=None, description="Button size, if not set, default (medium) size is used")
    btn_text: Optional[StrictStr] = Field(default=None, description="Button text, has to be set if the block is a button")
    btn_color: Optional[StrictStr] = Field(default=None, description="Button color in hex format, default (#415BF5) is used if not set")
    btn_target: Optional[ButtonTarget] = Field(default=None, description="Button target url, default (_blank) is used if not set")
    btn_position: Optional[ButtonPosition] = Field(default=None, description="Button position, default (center) is used if not set")
    btn_text_color: Optional[StrictStr] = Field(default=None, description="Button text color, default (#FFFFFF) is used if not set")
    pdf_id: Optional[StrictStr] = Field(default=None, description="PDF file id from the file storage service, file is served read-only")
    __properties: ClassVar[List[str]] = ["link", "file_id", "audio_id", "payload", "btn_url", "btn_font", "btn_size", "btn_text", "btn_color", "btn_target", "btn_position", "btn_text_color", "pdf_id"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Content from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Content from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "link": obj.get("link"),
            "file_id": obj.get("file_id"),
            "audio_id": obj.get("audio_id"),
            "payload": obj.get("payload"),
            "btn_url": obj.get("btn_url"),
            "btn_font": obj.get("btn_font"),
            "btn_size": obj.get("btn_size"),
            "btn_text": obj.get("btn_text"),
            "btn_color": obj.get("btn_color"),
            "btn_target": obj.get("btn_target"),
            "btn_position": obj.get("btn_position"),
            "btn_text_color": obj.get("btn_text_color"),
            "pdf_id": obj.get("pdf_id")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course import Course

class TestCourse(unittest.TestCase):
    """Course unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Course:
        """Test Course
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Course`
        """
        model = Course()
        if include_optional:
            return Course(
                title = '',
                image_id = '',
                description = '',
                url = '',
                payload = '',
                module_view_type = 'list',
                payment_type = 'paid',
                course_access_type = 'subscription',
                number_days_access = 56,
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                available_at = 56,
                launch_date_enabled = True,
                launch_date = 56,
                id = 56,
                portal_id = 56,
                order = 56,
                category = '',
                category_id = 56,
                sales_page_landing_id = 56,
                permalink = '',
                enable_double_optin = True,
                one_more_landing_id = 56,
                one_more_step_link = '',
                one_more_step_landing_id = 56,
                created_at_epoch = 56,
                modules = [
                    public_api_server_connector_v2.models.course_module.CourseModule(
                        mandatory = True, 
                        is_published = True, 
                        is_active = True, 
                        title = '', 
                        public_description = '', 
                        short_description = '', 
                        image_id = '', 
                        available_at = 56, 
                        id = 56, 
                        course_id = 56, 
                        order = 56, 
                        submodules = [
                            public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                                order = 56, 
                                title = '', 
                                is_published = True, 
                                id = 56, 
                                module_id = 56, 
                                created_at = 56, )
                            ], 
                        lessons = [
                            public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                                submodule_id = 56, 
                                thread_id = 56, 
                                lesson_type = null, 
                                image_id = '', 
                                title = '', 
                                payload = '', 
                                is_active = True, 
                                is_published = True, 
                                mandatory = True, 
                                id = 56, 
                                module_id = 56, 
                                order = 56, 
                                public_key = '', 
                                content_blocks = [
                                    public_api_server_connector_v2.models.content_block.ContentBlock(
                                        block_type = null, 
                                        order = 56, 
                                        is_expanded = True, 
                                        content = null, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], 
                                attached_files = [
                                    public_api_server_connector_v2.models.attached_file.AttachedFile(
                                        order = 56, 
                                        file_id = 56, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], )
                            ], )
                    ],
                content_blocks = [
                    public_api_server_connector_v2.models.course_content_block.CourseContentBlock(
                        block_type = 'text', 
                        order = 56, 
                        is_expanded = True, 
                        content = public_api_server_connector_v2.models.content.Content(
                            link = '', 
                            file_id = '', 
                            audio_id = '', 
                            payload = '', 
                            btn_url = '', 
                            btn_font = '', 
                            btn_size = null, 
                            btn_text = '', 
                            btn_color = '', 
                            btn_target = null, 
                            btn_position = null, 
                            btn_text_color = '', 
                            pdf_id = '', ), 
                        id = 56, 
                        course_id = 56, 
                        created_at = 56, )
                    ]
            )
        else:
            return Course(
                title = '',
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                id = 56,
                portal_id = 56,
                order = 56,
                created_at_epoch = 56,
                modules = [
                    public_api_server_connector_v2.models.course_module.CourseModule(
                        mandatory = True, 
                        is_published = True, 
                        is_active = True, 
                        title = '', 
                        public_description = '', 
                        short_description = '', 
                        image_id = '', 
                        available_at = 56, 
                        id = 56, 
                        course_id = 56, 
                        order = 56, 
                        submodules = [
                            public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                                order = 56, 
                                title = '', 
                                is_published = True, 
                                id = 56, 
                                module_id = 56, 
                                created_at = 56, )
                            ], 
                        lessons = [
                            public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                                submodule_id = 56, 
                                thread_id = 56, 
                                lesson_type = null, 
                                image_id = '', 
                                title = '', 
                                payload = '', 
                                is_active = True, 
                                is_published = True, 
                                mandatory = True, 
                                id = 56, 
                                module_id = 56, 
                                order = 56, 
                                public_key = '', 
                                content_blocks = [
                                    public_api_server_connector_v2.models.content_block.ContentBlock(
                                        block_type = null, 
                                        order = 56, 
                                        is_expanded = True, 
                                        content = null, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], 
                                attached_files = [
                                    public_api_server_connector_v2.models.attached_file.AttachedFile(
                                        order = 56, 
                                        file_id = 56, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], )
                            ], )
                    ],
                content_blocks = [
                    public_api_server_connector_v2.models.course_content_block.CourseContentBlock(
                        block_type = 'text', 
                        order = 56, 
                        is_expanded = True, 
                        content = public_api_server_connector_v2.models.content.Content(
                            link = '', 
                            file_id = '', 
                            audio_id = '', 
                            payload = '', 
                            btn_url = '', 
                            btn_font = '', 
                            btn_size = null, 
                            btn_text = '', 
                            btn_color = '', 
                            btn_target = null, 
                            btn_position = null, 
                            btn_text_color = '', 
                            pdf_id = '', ), 
                        id = 56, 
                        course_id = 56, 
                        created_at = 56, )
                    ],
        )
        """

    def testCourse(self):
        """Test Course"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ModuleLessonPatch(BaseModel):
    """
    ModuleLessonPatch
    """ # noqa: E501
    submodule_id: Optional[StrictInt] = Field(default=None, description="ID of the submodule this lesson belongs to, if not set, it will be not updated")
    thread_id: Optional[StrictInt] = Field(default=None, description="ID of the community thread this lesson belongs to, if not set, it will be not updated")
    image_id: Optional[StrictStr] = Field(default=None, description="ID of the image associated with the lesson, if not set, it will be not updated")
    order: Optional[StrictInt] = Field(default=None, description="Order of the lesson in the module, if not set, it will be not updated")
    title: Optional[StrictStr] = Field(default=None, description="Title of the lesson, if not set, it will be not updated")
    payload: Optional[StrictStr] = Field(default=None, description="Payload of the lesson, if not set, it will be not updated")
    is_active: Optional[StrictBool] = Field(default=None, description="Whether the lesson is active or not, if not set, it will be not updated")
    is_published: Optional[StrictBool] = Field(default=None, description="Whether the lesson is published or not, if not set, it will be not updated")
    mandatory: Optional[StrictBool] = Field(default=None, description="Whether the lesson is mandatory or not, if not set, it will be not updated")
    __properties: ClassVar[List[str]] = ["submodule_id", "thread_id", "image_id", "order", "title", "payload", "is_active", "is_published", "mandatory"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModuleLessonPatch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModuleLessonPatch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "submodule_id": obj.get("submodule_id"),
            "thread_id": obj.get("thread_id"),
            "image_id": obj.get("image_id"),
            "order": obj.get("order"),
            "title": obj.get("title"),
            "payload": obj.get("payload"),
            "is_active": obj.get("is_active"),
            "is_published": obj.get("is_published"),
            "mandatory": obj.get("mandatory")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.health_api import HealthApi


class TestHealthApi(unittest.IsolatedAsyncioTestCase):
    """HealthApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = HealthApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_health_health_check(self) -> None:
        """Test case for health_health_check

        Health Check
        """
        pass


if __name__ == '__main__':
    unittest.main()
